@@ -5,7 +5,7 @@ use Socket;
 use IO::Socket::INET;
 use Scalar::Util 'reftype';
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
  
 $| = 1;
 
@@ -95,7 +95,7 @@ sub pwhois {
         my $resolved = $self->resolveReq($elmt);
         if ($resolved) {
             $request .= "$resolved\n";
-	    push @req_new, $elmt;
+            push @req_new, $elmt;
         }
     }
     $request .= "end\n";
@@ -150,6 +150,7 @@ sub printReport {
         for my $key (sort keys %{$what->{$req}}) {
             $report .= sprintf("%-22s : %s\n", $key, $what->{$req}{$key});
         }
+        $report .= "\n";
     }
     return $report;
 }
@@ -172,7 +173,7 @@ Net::pWhoIs - Client library for Prefix WhoIs (pWhois)
         207.20.243.105
         67.225.131.208
         perlmonks.org
-	brokenhost.brokendomain.co
+        brokenhost.brokendomain.co
         8.8.8.8
         12.12.12.12
         ftp2.freebsd.org
@@ -190,13 +191,13 @@ Net::pWhoIs - Client library for Prefix WhoIs (pWhois)
     # Or manipulate the data yourself.
     for my $req (keys %{$output}) {
         # req contains queried item.
-	print $req, "\n";
+        print $req, "\n";
         for my $key (keys %{$output->{$req}}) {
-	    # key contains name of pwhois query result item.  Output ref contains value of pwhois query result item.
+            # key contains name of pwhois query result item.  Output ref contains value of pwhois query result item.
             printf("%s : %s\n", $key, $output->{$req}{$key});
         }
 
-	# Or grab it direct.
+        # Or grab it direct.
         print $output->{$req}{'city'}, "\n";
         print $output->{$req}{'org-name'}, "\n";
     }
@@ -245,6 +246,43 @@ An optional method which generates a formated report to stdout.  Accepts returne
 
 A full featured client is included: pwhoiscli.pl.  Pass it hostnames or IP seperated by space.
 
+    ./pwhoiscli.pl ftp4.freebsd.org cpan.org
+    Request: ftp4.freebsd.org
+    as-org-name            : Internet Systems Consortium, Inc.
+    as-path                : 852 6939 1280
+    cache-date             : 1650437752
+    city                   : Newmarket
+    country                : United States of America
+    country-code           : US
+    ip                     : 149.20.1.200
+    latitude               : 43.075798
+    longitude              : -70.942732
+    net-name               : ISC-NET3
+    org-name               : Internet Systems Consortium, Inc.
+    origin-as              : 1280
+    prefix                 : 149.20.1.0/24
+    region                 : New Hampshire
+    route-originated-date  : Mar 22 2022 00:21:20
+    route-originated-ts    : 1647908480
+
+    Request: cpan.org
+    as-org-name            : Packet Host, Inc.
+    as-path                : 8220 1299 54825
+    cache-date             : 1650437752
+    city                   : Parsippany
+    country                : United States of America
+    country-code           : US
+    ip                     : 139.178.67.96
+    latitude               : 40.857880
+    longitude              : -74.425990
+    net-name               : PACKET-HOST-139-178-64-0
+    org-name               : Packet Host Inc
+    origin-as              : 54825
+    prefix                 : 139.178.64.0/22
+    region                 : New Jersey
+    route-originated-date  : Apr 12 2022 05:26:23
+    route-originated-ts    : 1649741183
+
 =head1 OUTPUT HASHREF KEYS
 
 The following is the list hashref keys returned by pwhois.
